@@ -6,38 +6,38 @@
 
 #include "DummyTest.h"
 #include "DiscoverBackendsFactory.h"
-#include <resources/ResourcesUpdatesModel.h>
-#include <UpdateModel/UpdateModel.h>
-#include <QAbstractItemModelTester>
-#include <resources/ResourcesModel.h>
-#include <resources/ResourcesProxyModel.h>
-#include <resources/AbstractBackendUpdater.h>
 #include <ApplicationAddonsModel.h>
-#include <Transaction/TransactionModel.h>
+#include <Category/CategoryModel.h>
+#include <QAbstractItemModelTester>
+#include <QTest>
 #include <ReviewsBackend/ReviewsModel.h>
 #include <ScreenshotsModel.h>
-#include <Category/CategoryModel.h>
-#include <QTest>
+#include <Transaction/TransactionModel.h>
+#include <UpdateModel/UpdateModel.h>
+#include <resources/AbstractBackendUpdater.h>
+#include <resources/ResourcesModel.h>
+#include <resources/ResourcesProxyModel.h>
+#include <resources/ResourcesUpdatesModel.h>
 
 #include <QtTest>
-#include <QAction>
 
 QTEST_MAIN(DummyTest)
 
-AbstractResourcesBackend* backendByName(ResourcesModel* m, const QString& name)
+AbstractResourcesBackend *backendByName(ResourcesModel *m, const QString &name)
 {
-    QVector<AbstractResourcesBackend*> backends = m->backends();
-    foreach(AbstractResourcesBackend* backend, backends) {
-        if(QString::fromLatin1(backend->metaObject()->className()) == name) {
+    QVector<AbstractResourcesBackend *> backends = m->backends();
+    foreach (AbstractResourcesBackend *backend, backends) {
+        if (QString::fromLatin1(backend->metaObject()->className()) == name) {
             return backend;
         }
     }
     return nullptr;
 }
 
-DummyTest::DummyTest(QObject* parent): QObject(parent)
+DummyTest::DummyTest(QObject *parent)
+    : QObject(parent)
 {
-    DiscoverBackendsFactory::setRequestedBackends({ QStringLiteral("dummy-backend") });
+    DiscoverBackendsFactory::setRequestedBackends({QStringLiteral("dummy-backend")});
 
     m_model = new ResourcesModel(QStringLiteral("dummy-backend"), this);
     m_appBackend = backendByName(m_model, QStringLiteral("DummyBackend"));
@@ -48,16 +48,18 @@ DummyTest::DummyTest(QObject* parent): QObject(parent)
 void DummyTest::initTestCase()
 {
     QVERIFY(m_appBackend);
-    while(m_appBackend->isFetching()) {
+    while (m_appBackend->isFetching()) {
         QSignalSpy spy(m_appBackend, &AbstractResourcesBackend::fetchingChanged);
         QVERIFY(spy.wait());
     }
 }
 
-QVector<AbstractResource*> fetchResources(ResultsStream* stream)
+QVector<AbstractResource *> fetchResources(ResultsStream *stream)
 {
-    QVector<AbstractResource*> ret;
-    QObject::connect(stream, &ResultsStream::resourcesFound, stream, [&ret](const QVector<AbstractResource*>& res) { ret += res; });
+    QVector<AbstractResource *> ret;
+    QObject::connect(stream, &ResultsStream::resourcesFound, stream, [&ret](const QVector<AbstractResource *> &res) {
+        ret += res;
+    });
     QSignalSpy spy(stream, &ResultsStream::destroyed);
     Q_ASSERT(spy.wait());
     return ret;
@@ -69,7 +71,7 @@ void DummyTest::testReadData()
 
     QCOMPARE(m_appBackend->property("startElements").toInt() * 2, resources.size());
     QBENCHMARK {
-        for(AbstractResource* res: resources) {
+        for (AbstractResource *res : resources) {
             QVERIFY(!res->name().isEmpty());
         }
     }
@@ -79,7 +81,7 @@ void DummyTest::testProxy()
 {
     ResourcesProxyModel pm;
     QSignalSpy spy(&pm, &ResourcesProxyModel::busyChanged);
-//     QVERIFY(spy.wait());
+    // QVERIFY(spy.wait());
     QVERIFY(!pm.isBusy());
 
     pm.setFiltersFromCategory(CategoryModel::global()->rootCategories().first());
@@ -106,7 +108,7 @@ void DummyTest::testProxySorting()
 {
     ResourcesProxyModel pm;
     QSignalSpy spy(&pm, &ResourcesProxyModel::busyChanged);
-//     QVERIFY(spy.wait());
+    // QVERIFY(spy.wait());
     QVERIFY(!pm.isBusy());
 
     pm.setFiltersFromCategory(CategoryModel::global()->rootCategories().first());
@@ -119,11 +121,11 @@ void DummyTest::testProxySorting()
 
     QCOMPARE(m_appBackend->property("startElements").toInt() * 2, pm.rowCount());
     QVariant lastRatingCount;
-    for(int i=0, rc=pm.rowCount(); i<rc; ++i) {
+    for (int i = 0, rc = pm.rowCount(); i < rc; ++i) {
         const QModelIndex mi = pm.index(i, 0);
 
         const auto value = mi.data(pm.sortRole());
-        QVERIFY(i==0 || value <= lastRatingCount);
+        QVERIFY(i == 0 || value <= lastRatingCount);
         lastRatingCount = value;
     }
 }
@@ -131,14 +133,14 @@ void DummyTest::testProxySorting()
 void DummyTest::testFetch()
 {
     const auto resources = fetchResources(m_appBackend->search({}));
-    QCOMPARE(m_appBackend->property("startElements").toInt()*2, resources.count());
+    QCOMPARE(m_appBackend->property("startElements").toInt() * 2, resources.count());
 
-    //fetches updates, adds new things
+    // fetches updates, adds new things
     m_appBackend->checkForUpdates();
     QSignalSpy spy(m_model, &ResourcesModel::allInitialized);
     QVERIFY(spy.wait(80000));
     auto resources2 = fetchResources(m_appBackend->search({}));
-    QCOMPARE(m_appBackend->property("startElements").toInt()*4, resources2.count());
+    QCOMPARE(m_appBackend->property("startElements").toInt() * 4, resources2.count());
 }
 
 void DummyTest::testSort()
@@ -151,7 +153,7 @@ void DummyTest::testSort()
         pm.sort(0);
         QCOMPARE(pm.sortOrder(), Qt::AscendingOrder);
         QString last;
-        for(int i = 0, count = pm.rowCount(); i<count; ++i) {
+        for (int i = 0, count = pm.rowCount(); i < count; ++i) {
             const QString current = pm.index(i, 0).data(pm.sortRole()).toString();
             if (!last.isEmpty()) {
                 QCOMPARE(c.compare(last, current), -1);
@@ -162,10 +164,10 @@ void DummyTest::testSort()
 
     QBENCHMARK_ONCE {
         pm.setSortRole(ResourcesProxyModel::SortableRatingRole);
-        int last=-1;
-        for(int i = 0, count = pm.rowCount(); i<count; ++i) {
+        int last = -1;
+        for (int i = 0, count = pm.rowCount(); i < count; ++i) {
             const int current = pm.index(i, 0).data(pm.sortRole()).toInt();
-            QVERIFY(last<=current);
+            QVERIFY(last <= current);
             last = current;
         }
     }
@@ -178,7 +180,7 @@ void DummyTest::testInstallAddons()
 
     const auto resources = fetchResources(m_appBackend->search(filter));
     QCOMPARE(resources.count(), 1);
-    AbstractResource* res = resources.first();
+    AbstractResource *res = resources.first();
     QVERIFY(res);
 
     ApplicationAddonsModel m;
@@ -187,7 +189,7 @@ void DummyTest::testInstallAddons()
     QCOMPARE(m.rowCount(), res->addonsInformation().count());
     QCOMPARE(res->addonsInformation().at(0).isInstalled(), false);
 
-    QString firstAddonName = m.data(m.index(0,0)).toString();
+    QString firstAddonName = m.data(m.index(0, 0)).toString();
     m.changeState(firstAddonName, true);
     QVERIFY(m.hasChanges());
 
@@ -196,15 +198,15 @@ void DummyTest::testInstallAddons()
     QVERIFY(sR.wait());
     QVERIFY(!m.hasChanges());
 
-    QCOMPARE(m.data(m.index(0,0)).toString(), firstAddonName);
+    QCOMPARE(m.data(m.index(0, 0)).toString(), firstAddonName);
     QCOMPARE(res->addonsInformation().at(0).name(), firstAddonName);
     QCOMPARE(res->addonsInformation().at(0).isInstalled(), true);
 
-    m.changeState(m.data(m.index(1,0)).toString(), true);
+    m.changeState(m.data(m.index(1, 0)).toString(), true);
     QVERIFY(m.hasChanges());
-    for(int i=0, c=m.rowCount(); i<c; ++i) {
+    for (int i = 0, c = m.rowCount(); i < c; ++i) {
         const auto idx = m.index(i, 0);
-        QCOMPARE(idx.data(Qt::CheckStateRole).toInt(), int(i<=1 ? Qt::Checked : Qt::Unchecked));
+        QCOMPARE(idx.data(Qt::CheckStateRole).toInt(), int(i <= 1 ? Qt::Checked : Qt::Unchecked));
         QVERIFY(!idx.data(ApplicationAddonsModel::PackageNameRole).toString().isEmpty());
     }
     m.discardChanges();
@@ -218,7 +220,7 @@ void DummyTest::testReviewsModel()
 
     const auto resources = fetchResources(m_appBackend->search(filter));
     QCOMPARE(resources.count(), 1);
-    AbstractResource* res = resources.first();
+    AbstractResource *res = resources.first();
     QVERIFY(res);
 
     ReviewsModel m;
@@ -226,13 +228,13 @@ void DummyTest::testReviewsModel()
     m.setResource(res);
     m.fetchMore();
 
-    QVERIFY(m.rowCount()>0);
+    QVERIFY(m.rowCount() > 0);
 
-    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0,0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::None);
+    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0, 0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::None);
     m.markUseful(0, true);
-    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0,0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::Yes);
+    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0, 0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::Yes);
     m.markUseful(0, false);
-    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0,0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::No);
+    QCOMPARE(ReviewsModel::UserChoice(m.data(m.index(0, 0), ReviewsModel::UsefulChoice).toInt()), ReviewsModel::No);
 
     const auto resources2 = fetchResources(m_appBackend->search(filter));
     QCOMPARE(resources2.count(), 1);
@@ -241,7 +243,7 @@ void DummyTest::testReviewsModel()
     m.fetchMore();
 
     QSignalSpy spy(&m, &ReviewsModel::rowsChanged);
-    QVERIFY(m.rowCount()>0);
+    QVERIFY(m.rowCount() > 0);
 }
 
 void DummyTest::testUpdateModel()
@@ -254,7 +256,7 @@ void DummyTest::testUpdateModel()
     new QAbstractItemModelTester(&model, &model);
     model.setBackend(&ruModel);
 
-    QCOMPARE(model.rowCount(), backend->property("startElements").toInt()*2);
+    QCOMPARE(model.rowCount(), backend->property("startElements").toInt() * 2);
     QCOMPARE(model.hasUpdates(), true);
 }
 
@@ -268,17 +270,17 @@ void DummyTest::testScreenshotsModel()
 
     const auto resources = fetchResources(m_appBackend->search(filter));
     QCOMPARE(resources.count(), 1);
-    AbstractResource* res = resources.first();
+    AbstractResource *res = resources.first();
     QVERIFY(res);
     m.setResource(res);
     QCOMPARE(res, m.resource());
 
-    int c=m.rowCount();
-    for(int i=0; i<c; ++i) {
+    int c = m.rowCount();
+    for (int i = 0; i < c; ++i) {
         const auto idx = m.index(i, 0);
         QVERIFY(!idx.data(ScreenshotsModel::ThumbnailUrl).isNull());
         QVERIFY(!idx.data(ScreenshotsModel::ScreenshotUrl).isNull());
     }
 }
 
-//TODO test cancel transaction
+// TODO test cancel transaction
