@@ -7,22 +7,22 @@
 
 #include "FwupdBackend.h"
 #include "FwupdResource.h"
-#include "FwupdTransaction.h"
 #include "FwupdSourcesBackend.h"
-#include <resources/StandardBackendUpdater.h>
-#include <resources/SourcesModel.h>
+#include "FwupdTransaction.h"
 #include <Transaction/Transaction.h>
+#include <resources/SourcesModel.h>
+#include <resources/StandardBackendUpdater.h>
 
-#include <QCoreApplication>
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KConfigGroup>
 #include <KSharedConfig>
+#include <QCoreApplication>
 
 DISCOVER_BACKEND_PLUGIN(FwupdBackend)
 
-FwupdBackend::FwupdBackend(QObject* parent)
+FwupdBackend::FwupdBackend(QObject *parent)
     : AbstractResourcesBackend(parent)
     , client(fwupd_client_new())
     , m_updater(new StandardBackendUpdater(this))
@@ -37,12 +37,12 @@ FwupdBackend::FwupdBackend(QObject* parent)
 
 QMap<GChecksumType, QCryptographicHash::Algorithm> FwupdBackend::gchecksumToQChryptographicHash()
 {
-    static QMap<GChecksumType,QCryptographicHash::Algorithm> map;
+    static QMap<GChecksumType, QCryptographicHash::Algorithm> map;
     if (map.isEmpty()) {
-        map.insert(G_CHECKSUM_SHA1,QCryptographicHash::Sha1);
-        map.insert(G_CHECKSUM_SHA256,QCryptographicHash::Sha256);
-        map.insert(G_CHECKSUM_SHA512,QCryptographicHash::Sha512);
-        map.insert(G_CHECKSUM_MD5,QCryptographicHash::Md5);
+        map.insert(G_CHECKSUM_SHA1, QCryptographicHash::Sha1);
+        map.insert(G_CHECKSUM_SHA256, QCryptographicHash::Sha256);
+        map.insert(G_CHECKSUM_SHA512, QCryptographicHash::Sha512);
+        map.insert(G_CHECKSUM_MD5, QCryptographicHash::Md5);
     }
     return map;
 }
@@ -55,7 +55,7 @@ FwupdBackend::~FwupdBackend()
     g_object_unref(client);
 }
 
-void FwupdBackend::addResource(FwupdResource* res)
+void FwupdBackend::addResource(FwupdResource *res)
 {
     res->setParent(this);
     auto &r = m_resources[res->packageName()];
@@ -67,20 +67,18 @@ void FwupdBackend::addResource(FwupdResource* res)
     Q_ASSERT(m_resources.value(res->packageName()) == res);
 }
 
-FwupdResource * FwupdBackend::createRelease(FwupdDevice *device)
+FwupdResource *FwupdBackend::createRelease(FwupdDevice *device)
 {
     FwupdRelease *release = fwupd_device_get_release_default(device);
-    FwupdResource* res = new FwupdResource(device, QString::fromUtf8(fwupd_release_get_appstream_id(release)), this);
+    FwupdResource *res = new FwupdResource(device, QString::fromUtf8(fwupd_release_get_appstream_id(release)), this);
     res->setReleaseDetails(release);
 
     /* the same as we have already */
-    if (qstrcmp(fwupd_device_get_version(device), fwupd_release_get_version(release)) == 0)
-    {
+    if (qstrcmp(fwupd_device_get_version(device), fwupd_release_get_version(release)) == 0) {
         qWarning() << "Fwupd Error: same firmware version as installed";
     }
 
     return res;
-
 }
 
 void FwupdBackend::addUpdates()
@@ -88,8 +86,7 @@ void FwupdBackend::addUpdates()
     g_autoptr(GError) error = nullptr;
     g_autoptr(GPtrArray) devices = fwupd_client_get_devices(client, m_cancellable, &error);
 
-    if (!devices)
-    {
+    if (!devices) {
         if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO))
             qDebug() << "Fwupd Info: No Devices Found";
         else
@@ -97,8 +94,7 @@ void FwupdBackend::addUpdates()
         return;
     }
 
-    for(uint i = 0; i < devices->len && !g_cancellable_is_cancelled(m_cancellable); i++)
-    {
+    for (uint i = 0; i < devices->len && !g_cancellable_is_cancelled(m_cancellable); i++) {
         FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
 
         if (!fwupd_device_has_flag(device, FWUPD_DEVICE_FLAG_SUPPORTED))
@@ -115,15 +111,11 @@ void FwupdBackend::addUpdates()
         if (rels) {
             fwupd_device_add_release(device, (FwupdRelease *)g_ptr_array_index(rels, 0));
             auto res = createApp(device);
-            if (!res)
-            {
+            if (!res) {
                 qWarning() << "Fwupd Error: Cannot Create App From Device" << fwupd_device_get_name(device);
-            }
-            else
-            {
+            } else {
                 QString longdescription;
-                for(uint j = 0; j < rels->len; j++)
-                {
+                for (uint j = 0; j < rels->len; j++) {
                     FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(rels, j);
                     if (!fwupd_release_get_description(release))
                         continue;
@@ -160,13 +152,14 @@ QByteArray FwupdBackend::getChecksum(const QString &filename, QCryptographicHash
     return hash.result().toHex();
 }
 
-FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
+FwupdResource *FwupdBackend::createApp(FwupdDevice *device)
 {
     FwupdRelease *release = fwupd_device_get_release_default(device);
     QScopedPointer<FwupdResource> app(createRelease(device));
 
     if (!app->isLiveUpdatable()) {
-        qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]" << "cannot be updated ";
+        qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]"
+                   << "cannot be updated";
         return nullptr;
     }
 
@@ -188,7 +181,7 @@ FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
 
     const QUrl update_uri(QString::fromUtf8(fwupd_release_get_uri(release)));
     if (!update_uri.isValid()) {
-        qWarning() << "Fwupd Error: No Update URI available for" << app->name() <<  "[" << app->id() << "]";
+        qWarning() << "Fwupd Error: No Update URI available for" << app->name() << "[" << app->id() << "]";
         return nullptr;
     }
 
@@ -209,16 +202,16 @@ FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
 
 void FwupdBackend::handleError(GError *perror)
 {
-    //TODO: localise the error message
+    // TODO: localise the error message
     if (perror && !g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) && !g_error_matches(perror, FWUPD_ERROR, FWUPD_ERROR_NOTHING_TO_DO)) {
         const QString msg = QString::fromUtf8(perror->message);
-        QTimer::singleShot(0, this, [this, msg](){
+        QTimer::singleShot(0, this, [this, msg]() {
             Q_EMIT passiveMessage(msg);
         });
         qWarning() << "Fwupd Error" << perror->code << perror->message;
     }
-//     else
-//         qDebug() << "Fwupd skipped" << perror->code << perror->message;
+    // else
+    //     qDebug() << "Fwupd skipped" << perror->code << perror->message;
 }
 
 QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
@@ -226,8 +219,7 @@ QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
     const QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
     const QString cacheDirFile = cacheDir.filePath(kind);
 
-    if (!QFileInfo::exists(cacheDirFile) && !cacheDir.mkpath(kind))
-    {
+    if (!QFileInfo::exists(cacheDirFile) && !cacheDir.mkpath(kind)) {
         qWarning() << "Fwupd Error: cannot make  cache directory!";
         return {};
     }
@@ -235,9 +227,9 @@ QString FwupdBackend::cacheFile(const QString &kind, const QString &basename)
     return cacheDir.filePath(kind + QLatin1Char('/') + basename);
 }
 
-static void fwupd_client_get_devices_cb (GObject */*source*/, GAsyncResult *res, gpointer user_data)
+static void fwupd_client_get_devices_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
 {
-    FwupdBackend *helper = (FwupdBackend *) user_data;
+    FwupdBackend *helper = (FwupdBackend *)user_data;
     g_autoptr(GError) error = nullptr;
     auto array = fwupd_client_get_devices_finish(helper->client, res, &error);
     if (!error)
@@ -248,10 +240,10 @@ static void fwupd_client_get_devices_cb (GObject */*source*/, GAsyncResult *res,
 
 void FwupdBackend::setDevices(GPtrArray *devices)
 {
-    for(uint i = 0; devices && i < devices->len; i++) {
-        FwupdDevice *device = (FwupdDevice *) g_ptr_array_index(devices, i);
+    for (uint i = 0; devices && i < devices->len; i++) {
+        FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
 
-        if (!fwupd_device_has_flag (device, FWUPD_DEVICE_FLAG_SUPPORTED))
+        if (!fwupd_device_has_flag(device, FWUPD_DEVICE_FLAG_SUPPORTED))
             continue;
 
         g_autoptr(GError) error = nullptr;
@@ -270,7 +262,7 @@ void FwupdBackend::setDevices(GPtrArray *devices)
         }
 
         auto res = new FwupdResource(device, this);
-        for (uint i=0; releases && i<releases->len; ++i) {
+        for (uint i = 0; releases && i < releases->len; ++i) {
             FwupdRelease *release = (FwupdRelease *)g_ptr_array_index(releases, i);
             if (res->installedVersion().toUtf8() == fwupd_release_get_version(release)) {
                 res->setReleaseDetails(release);
@@ -284,13 +276,13 @@ void FwupdBackend::setDevices(GPtrArray *devices)
     addUpdates();
 
     m_fetching = false;
-    emit fetchingChanged();
-    emit initialized();
+    Q_EMIT fetchingChanged();
+    Q_EMIT initialized();
 }
 
-static void fwupd_client_get_remotes_cb (GObject */*source*/, GAsyncResult *res, gpointer user_data)
+static void fwupd_client_get_remotes_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
 {
-    FwupdBackend *helper = (FwupdBackend *) user_data;
+    FwupdBackend *helper = (FwupdBackend *)user_data;
     g_autoptr(GError) error = nullptr;
     auto array = fwupd_client_get_remotes_finish(helper->client, res, &error);
     if (!error)
@@ -299,19 +291,18 @@ static void fwupd_client_get_remotes_cb (GObject */*source*/, GAsyncResult *res,
         helper->handleError(error);
 }
 
-static void fwupd_client_refresh_remote_cb (GObject */*source*/, GAsyncResult *res, gpointer user_data)
+static void fwupd_client_refresh_remote_cb(GObject * /*source*/, GAsyncResult *res, gpointer user_data)
 {
-    FwupdBackend *helper = (FwupdBackend *) user_data;
+    FwupdBackend *helper = (FwupdBackend *)user_data;
     g_autoptr(GError) error = nullptr;
-    fwupd_client_refresh_remote_finish(helper->client, res, &error);
-    if (error)
+    const bool successful = fwupd_client_refresh_remote_finish(helper->client, res, &error);
+    if (!successful)
         helper->handleError(error);
 }
 
 void FwupdBackend::setRemotes(GPtrArray *remotes)
 {
-    for(uint i = 0; remotes && i < remotes->len; i++)
-    {
+    for (uint i = 0; remotes && i < remotes->len; i++) {
         FwupdRemote *remote = (FwupdRemote *)g_ptr_array_index(remotes, i);
         if (!fwupd_remote_get_enabled(remote))
             continue;
@@ -330,13 +321,13 @@ void FwupdBackend::checkForUpdates()
 
     g_autoptr(GError) error = nullptr;
 
-    if (!fwupd_client_connect (client, m_cancellable, &error)) {
+    if (!fwupd_client_connect(client, m_cancellable, &error)) {
         handleError(error);
         return;
     }
 
     m_fetching = true;
-    emit fetchingChanged();
+    Q_EMIT fetchingChanged();
 
     fwupd_client_get_devices_async(client, m_cancellable, fwupd_client_get_devices_cb, this);
     fwupd_client_get_remotes_async(client, m_cancellable, fwupd_client_get_remotes_cb, this);
@@ -347,7 +338,7 @@ int FwupdBackend::updatesCount() const
     return m_updater->updatesCount();
 }
 
-ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& filter)
+ResultsStream *FwupdBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
     if (!filter.resourceUrl.isEmpty()) {
         if (filter.resourceUrl.scheme() == QLatin1String("fwupd")) {
@@ -359,13 +350,14 @@ ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& fil
     }
 
     auto stream = new ResultsStream(QStringLiteral("FwupdStream"));
-    auto f = [this, stream, filter] () {
-        QVector<AbstractResource*> ret;
-        foreach(AbstractResource* r, m_resources) {
+    auto f = [this, stream, filter]() {
+        QVector<AbstractResource *> ret;
+        foreach (AbstractResource *r, m_resources) {
             if (r->state() < filter.state)
                 continue;
 
-            if (filter.search.isEmpty() || r->name().contains(filter.search, Qt::CaseInsensitive) || r->comment().contains(filter.search, Qt::CaseInsensitive)) {
+            if (filter.search.isEmpty() || r->name().contains(filter.search, Qt::CaseInsensitive)
+                || r->comment().contains(filter.search, Qt::CaseInsensitive)) {
                 ret += r;
             }
         }
@@ -381,45 +373,43 @@ ResultsStream* FwupdBackend::search(const AbstractResourcesBackend::Filters& fil
     return stream;
 }
 
-ResultsStream * FwupdBackend::findResourceByPackageName(const QUrl& search)
+ResultsStream *FwupdBackend::findResourceByPackageName(const QUrl &search)
 {
     auto res = search.scheme() == QLatin1String("fwupd") ? m_resources.value(search.host().replace(QLatin1Char('.'), QLatin1Char(' '))) : nullptr;
-    if (!res)
-    {
+    if (!res) {
         return new ResultsStream(QStringLiteral("FwupdStream"), {});
-    }
-    else
-        return new ResultsStream(QStringLiteral("FwupdStream"), { res });
+    } else
+        return new ResultsStream(QStringLiteral("FwupdStream"), {res});
 }
 
-AbstractBackendUpdater* FwupdBackend::backendUpdater() const
+AbstractBackendUpdater *FwupdBackend::backendUpdater() const
 {
     return m_updater;
 }
 
-AbstractReviewsBackend* FwupdBackend::reviewsBackend() const
+AbstractReviewsBackend *FwupdBackend::reviewsBackend() const
 {
     return nullptr;
 }
 
-Transaction* FwupdBackend::installApplication(AbstractResource* app, const AddonList& addons)
+Transaction *FwupdBackend::installApplication(AbstractResource *app, const AddonList &addons)
 {
     Q_ASSERT(addons.isEmpty());
     return installApplication(app);
 }
 
-Transaction* FwupdBackend::installApplication(AbstractResource* app)
+Transaction *FwupdBackend::installApplication(AbstractResource *app)
 {
-	return new FwupdTransaction(qobject_cast<FwupdResource*>(app), this);
+    return new FwupdTransaction(qobject_cast<FwupdResource *>(app), this);
 }
 
-Transaction* FwupdBackend::removeApplication(AbstractResource* /*app*/)
+Transaction *FwupdBackend::removeApplication(AbstractResource * /*app*/)
 {
     qWarning() << "should not have reached here, it's not possible to uninstall a firmware";
     return nullptr;
 }
 
-ResultsStream* FwupdBackend::resourceForFile(const QUrl& path)
+ResultsStream *FwupdBackend::resourceForFile(const QUrl &path)
 {
     if (!path.isLocalFile())
         return new ResultsStream(QStringLiteral("FwupdStream-void"), {});
@@ -429,30 +419,25 @@ ResultsStream* FwupdBackend::resourceForFile(const QUrl& path)
     const QString fileName = path.fileName();
     QMimeDatabase db;
     QMimeType type = db.mimeTypeForFile(fileName);
-    FwupdResource* app = nullptr;
+    FwupdResource *app = nullptr;
 
-    if (type.isValid() && type.inherits(QStringLiteral("application/vnd.ms-cab-compressed")))
-    {
+    if (type.isValid() && type.inherits(QStringLiteral("application/vnd.ms-cab-compressed"))) {
         g_autofree gchar *filename = fileName.toUtf8().data();
         g_autoptr(GPtrArray) devices = fwupd_client_get_details(client, filename, nullptr, &error);
 
-        if (devices)
-        {
+        if (devices) {
             FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, 0);
             app = createRelease(device);
             app->setState(AbstractResource::None);
-            for(uint i = 1; i < devices->len; i++)
-            {
+            for (uint i = 1; i < devices->len; i++) {
                 FwupdDevice *device = (FwupdDevice *)g_ptr_array_index(devices, i);
-                FwupdResource* app_ = createRelease(device);
+                FwupdResource *app_ = createRelease(device);
                 app_->setState(AbstractResource::None);
             }
             addResource(app);
             connect(app, &FwupdResource::stateChanged, this, &FwupdBackend::updatesCountChanged);
             return new ResultsStream(QStringLiteral("FwupdStream-file"), {app});
-        }
-        else
-        {
+        } else {
             handleError(error);
         }
     }
