@@ -7,26 +7,26 @@
 
 #include "PackageKitNotifier.h"
 
-#include <QTimer>
-#include <QStandardPaths>
-#include <QRegularExpression>
-#include <QProcess>
-#include <QTextStream>
-#include <QDebug>
+#include <KConfigGroup>
+#include <KDesktopFile>
+#include <KLocalizedString>
 #include <KNotification>
 #include <PackageKit/Daemon>
 #include <PackageKit/Offline>
 #include <QDBusInterface>
+#include <QDebug>
 #include <QFile>
 #include <QFileSystemWatcher>
-#include <KLocalizedString>
-#include <KDesktopFile>
-#include <KConfigGroup>
+#include <QProcess>
+#include <QRegularExpression>
+#include <QStandardPaths>
+#include <QTextStream>
+#include <QTimer>
 
-#include "pk-offline-private.h"
 #include "libdiscover_backend_debug.h"
+#include "pk-offline-private.h"
 
-PackageKitNotifier::PackageKitNotifier(QObject* parent)
+PackageKitNotifier::PackageKitNotifier(QObject *parent)
     : BackendNotifierModule(parent)
     , m_securityUpdates(0)
     , m_normalUpdates(0)
@@ -34,12 +34,12 @@ PackageKitNotifier::PackageKitNotifier(QObject* parent)
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::transactionListChanged, this, &PackageKitNotifier::transactionListChanged);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::restartScheduled, this, &PackageKitNotifier::nowNeedsReboot);
-    connect(PackageKit::Daemon::global()->offline(), &PackageKit::Offline::changed, this, [this]{
+    connect(PackageKit::Daemon::global()->offline(), &PackageKit::Offline::changed, this, [this] {
         if (PackageKit::Daemon::global()->offline()->updateTriggered())
             nowNeedsReboot();
     });
 
-    //Check if there's packages after 5'
+    // Check if there's packages after 5'
     QTimer::singleShot(5 * 60 * 1000, this, &PackageKitNotifier::refreshDatabase);
 
     QTimer *regularCheck = new QTimer(this);
@@ -47,21 +47,21 @@ PackageKitNotifier::PackageKitNotifier(QObject* parent)
 
     const QString aptconfig = QStandardPaths::findExecutable(QStringLiteral("apt-config"));
     if (!aptconfig.isEmpty()) {
-        checkAptVariable(aptconfig, QLatin1String("Apt::Periodic::Update-Package-Lists"), [regularCheck](const QStringRef& value) {
+        checkAptVariable(aptconfig, QLatin1String("Apt::Periodic::Update-Package-Lists"), [regularCheck](const QStringRef &value) {
             bool ok;
             const int days = value.toInt(&ok);
             if (!ok || days == 0) {
-                regularCheck->setInterval(24 * 60 * 60 * 1000); //refresh at least once every day
+                regularCheck->setInterval(24 * 60 * 60 * 1000); // refresh at least once every day
                 regularCheck->start();
                 if (!value.isEmpty())
                     qWarning() << "couldn't understand value for timer:" << value;
             }
 
-            //if the setting is not empty, refresh will be carried out by unattended-upgrade
-            //https://wiki.debian.org/UnattendedUpgrades
+            // if the setting is not empty, refresh will be carried out by unattended-upgrade
+            // https://wiki.debian.org/UnattendedUpgrades
         });
     } else {
-        regularCheck->setInterval(24 * 60 * 60 * 1000); //refresh at least once every day
+        regularCheck->setInterval(24 * 60 * 60 * 1000); // refresh at least once every day
         regularCheck->start();
     }
 
@@ -72,13 +72,13 @@ PackageKitNotifier::PackageKitNotifier(QObject* parent)
     m_recheckTimer->setSingleShot(true);
     connect(m_recheckTimer, &QTimer::timeout, this, &PackageKitNotifier::recheckSystemUpdate);
 
-    QFileSystemWatcher* watcher = new QFileSystemWatcher(this);
+    QFileSystemWatcher *watcher = new QFileSystemWatcher(this);
     watcher->addPath(QStringLiteral(PK_OFFLINE_ACTION_FILENAME));
     connect(watcher, &QFileSystemWatcher::fileChanged, this, &PackageKitNotifier::nowNeedsReboot);
 
-    QTimer::singleShot(100, this, [this](){
-    if (QFile::exists(QStringLiteral(PK_OFFLINE_ACTION_FILENAME)))
-        nowNeedsReboot();
+    QTimer::singleShot(100, this, [this]() {
+        if (QFile::exists(QStringLiteral(PK_OFFLINE_ACTION_FILENAME)))
+            nowNeedsReboot();
     });
 }
 
@@ -102,32 +102,37 @@ void PackageKitNotifier::checkOfflineUpdates()
     if (!success) {
         const QString errorDetails = group.readEntry("ErrorDetails");
 
-        KNotification *notification = new KNotification(QStringLiteral("offlineupdate-failed"), KNotification::Persistent | KNotification::DefaultEvent);
+        KNotification *notification = new KNotification(QStringLiteral("OfflineUpdateFailed"), KNotification::Persistent | KNotification::DefaultEvent);
         notification->setIconName(QStringLiteral("error"));
         notification->setText(i18n("Offline Updates"));
-        notification->setText(i18np("Failed to update %1 package\n%2", "Failed to update %1 packages\n%2",
-                                    packages.count(), errorDetails));
+        notification->setText(i18np("Failed to update %1 package\n%2", "Failed to update %1 packages\n%2", packages.count(), errorDetails));
         notification->setActions(QStringList{i18nc("@action:button", "Open Discover"), i18nc("@action:button", "Repair System")});
 
-        connect(notification, &KNotification::action1Activated, this, [] () {
+        connect(notification, &KNotification::action1Activated, this, []() {
             QProcess::startDetached(QStringLiteral("plasma-discover"), QStringList());
         });
-        connect(notification, &KNotification::action2Activated, this, [this] () {
+        connect(notification, &KNotification::action2Activated, this, [this]() {
             auto trans = PackageKit::Daemon::global()->repairSystem();
-            connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details){
-                KNotification::event(QStringLiteral("offlineupdate-repair-failed"), i18n("Repair Failed"), i18n("Please report to your distribution: %1", details), {}, KNotification::Persistent, QStringLiteral("org.kde.discovernotifier"));
+            connect(trans, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error /*error*/, const QString &details) {
+                KNotification::event(QStringLiteral("OfflineUpdateRepairFailed"),
+                                     i18n("Repair Failed"),
+                                     xi18nc("@info", "%1<nl/>Please report this error to your distribution.", details),
+                                     {},
+                                     KNotification::Persistent,
+                                     QStringLiteral("org.kde.discovernotifier"));
             });
         });
 
         notification->sendEvent();
     } else {
-        KNotification *notification = new KNotification(QStringLiteral("offlineupdate-successful"));
+        KNotification *notification = new KNotification(QStringLiteral("OfflineUpdateSuccessful"));
         notification->setIconName(QStringLiteral("system-software-update"));
         notification->setTitle(i18n("Offline Updates"));
         notification->setText(i18np("Successfully updated %1 package", "Successfully updated %1 packages", packages.count()));
         notification->setActions(QStringList{i18nc("@action:button", "Open Discover")});
+        notification->setComponentName(QStringLiteral("discoverabstractnotifier"));
 
-        connect(notification, &KNotification::action1Activated, this, [] () {
+        connect(notification, &KNotification::action1Activated, this, []() {
             QProcess::startDetached(QStringLiteral("plasma-discover"), QStringList());
         });
 
@@ -140,7 +145,7 @@ void PackageKitNotifier::recheckSystemUpdateNeeded()
 {
     static bool first = true;
     if (first) {
-        //PKQt will emit these signals when it starts (bug?) and would trigger the system recheck before we've ever checked at all
+        // PKQt will Q_EMIT these signals when it starts (bug?) and would trigger the system recheck before we've ever checked at all
         connect(PackageKit::Daemon::global(), &PackageKit::Daemon::networkStateChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
         connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
         first = false;
@@ -159,7 +164,7 @@ void PackageKitNotifier::recheckSystemUpdate()
     }
 }
 
-void PackageKitNotifier::setupGetUpdatesTransaction(PackageKit::Transaction* trans)
+void PackageKitNotifier::setupGetUpdatesTransaction(PackageKit::Transaction *trans)
 {
     qCDebug(LIBDISCOVER_BACKEND_LOG) << "using..." << trans << trans->tid().path();
 
@@ -169,25 +174,25 @@ void PackageKitNotifier::setupGetUpdatesTransaction(PackageKit::Transaction* tra
     connect(trans, &PackageKit::Transaction::finished, this, &PackageKitNotifier::finished);
 }
 
-void PackageKitNotifier::package(PackageKit::Transaction::Info info, const QString &/*packageID*/, const QString &/*summary*/)
+void PackageKitNotifier::package(PackageKit::Transaction::Info info, const QString & /*packageID*/, const QString & /*summary*/)
 {
-    PackageKit::Transaction * trans = qobject_cast<PackageKit::Transaction *>(sender());
+    PackageKit::Transaction *trans = qobject_cast<PackageKit::Transaction *>(sender());
 
     switch (info) {
-        case PackageKit::Transaction::InfoBlocked:
-            break; //skip, we ignore blocked updates
-        case PackageKit::Transaction::InfoSecurity:
-            trans->setProperty("securityUpdates", trans->property("securityUpdates").toInt()+1);
-            break;
-        default:
-            trans->setProperty("normalUpdates", trans->property("normalUpdates").toInt()+1);
-            break;
+    case PackageKit::Transaction::InfoBlocked:
+        break; // skip, we ignore blocked updates
+    case PackageKit::Transaction::InfoSecurity:
+        trans->setProperty("securityUpdates", trans->property("securityUpdates").toInt() + 1);
+        break;
+    default:
+        trans->setProperty("normalUpdates", trans->property("normalUpdates").toInt() + 1);
+        break;
     }
 }
 
 void PackageKitNotifier::finished(PackageKit::Transaction::Exit /*exit*/, uint)
 {
-    const PackageKit::Transaction * trans = qobject_cast<PackageKit::Transaction *>(sender());
+    const PackageKit::Transaction *trans = qobject_cast<PackageKit::Transaction *>(sender());
 
     const uint normalUpdates = trans->property("normalUpdates").toInt();
     const uint securityUpdates = trans->property("securityUpdates").toInt();
@@ -211,11 +216,10 @@ bool PackageKitNotifier::hasSecurityUpdates()
     return m_securityUpdates > 0;
 }
 
-
-void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade /*type*/, const QString& name, const QString& description)
+void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade /*type*/, const QString &name, const QString &description)
 {
     auto a = new UpgradeAction(name, description, this);
-    connect(a, &UpgradeAction::triggered, this, [] (const QString &name) {
+    connect(a, &UpgradeAction::triggered, this, [](const QString &name) {
         PackageKit::Daemon::upgradeSystem(name, PackageKit::Transaction::UpgradeKindDefault);
     });
     Q_EMIT foundUpgradeAction(a);
@@ -234,11 +238,11 @@ void PackageKitNotifier::refreshDatabase()
     }
 }
 
-QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String& varname, const std::function<void(const QStringRef& val)> &func)
+QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String &varname, const std::function<void(const QStringRef &val)> &func)
 {
-    QProcess* process = new QProcess;
+    QProcess *process = new QProcess;
     process->start(aptconfig, {QStringLiteral("dump")});
-    connect(process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [func, process, varname](int code) {
+    connect(process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [func, process, varname](int code) {
         if (code != 0)
             return;
 
@@ -254,16 +258,16 @@ QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
         }
         func({});
     });
-    connect(process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), process, &QObject::deleteLater);
+    connect(process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), process, &QObject::deleteLater);
     return process;
 }
 
-void PackageKitNotifier::transactionListChanged(const QStringList& tids)
+void PackageKitNotifier::transactionListChanged(const QStringList &tids)
 {
     if (PackageKit::Daemon::global()->offline()->updateTriggered())
         return;
 
-    for (const auto &tid: tids) {
+    for (const auto &tid : tids) {
         if (m_transactions.contains(tid))
             continue;
 
@@ -275,7 +279,7 @@ void PackageKitNotifier::transactionListChanged(const QStringList& tids)
             }
         });
         connect(t, &PackageKit::Transaction::requireRestart, this, &PackageKitNotifier::onRequireRestart);
-        connect(t, &PackageKit::Transaction::finished, this, [this, t](){
+        connect(t, &PackageKit::Transaction::finished, this, [this, t]() {
             auto restart = t->property("requireRestart");
             if (!restart.isNull()) {
                 auto restartEvent = PackageKit::Transaction::Restart(restart.toInt());
@@ -300,7 +304,7 @@ void PackageKitNotifier::nowNeedsReboot()
 
 void PackageKitNotifier::onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID)
 {
-    PackageKit::Transaction* t = qobject_cast<PackageKit::Transaction*>(sender());
+    PackageKit::Transaction *t = qobject_cast<PackageKit::Transaction *>(sender());
     t->setProperty("requireRestart", qMax<int>(t->property("requireRestart").toInt(), type));
     qCDebug(LIBDISCOVER_BACKEND_LOG) << "RESTART" << type << "is required for package" << packageID;
 }
