@@ -8,9 +8,9 @@
 #define DISCOVERNOTIFIERMODULE_H
 
 #include <BackendNotifierModule.h>
+#include <QPointer>
 #include <QStringList>
 #include <QTimer>
-#include <QPointer>
 
 #include <KConfigWatcher>
 #include <KNotification>
@@ -21,13 +21,13 @@ class UnattendedUpdates;
 
 class DiscoverNotifier : public QObject
 {
-Q_OBJECT
-Q_PROPERTY(QStringList modules READ loadedModules CONSTANT)
-Q_PROPERTY(QString iconName READ iconName NOTIFY stateChanged)
-Q_PROPERTY(QString message READ message NOTIFY stateChanged)
-Q_PROPERTY(State state READ state NOTIFY stateChanged)
-Q_PROPERTY(bool needsReboot READ needsReboot NOTIFY needsRebootChanged)
-Q_PROPERTY(bool isBusy READ isBusy NOTIFY busyChanged)
+    Q_OBJECT
+    Q_PROPERTY(QStringList modules READ loadedModules CONSTANT)
+    Q_PROPERTY(QString iconName READ iconName NOTIFY stateChanged)
+    Q_PROPERTY(QString message READ message NOTIFY stateChanged)
+    Q_PROPERTY(State state READ state NOTIFY stateChanged)
+    Q_PROPERTY(bool needsReboot READ needsReboot NOTIFY needsRebootChanged)
+    Q_PROPERTY(bool isBusy READ isBusy NOTIFY busyChanged)
 public:
     enum State {
         NoUpdates,
@@ -39,20 +39,32 @@ public:
     };
     Q_ENUM(State)
 
-    explicit DiscoverNotifier(QObject* parent = nullptr);
+    explicit DiscoverNotifier(QObject *parent = nullptr);
     ~DiscoverNotifier() override;
 
     State state() const;
     QString iconName() const;
     QString message() const;
-    bool hasUpdates() const { return m_hasUpdates; }
-    bool hasSecurityUpdates() const { return m_hasSecurityUpdates; }
+    bool hasUpdates() const
+    {
+        return m_hasUpdates;
+    }
+    bool hasSecurityUpdates() const
+    {
+        return m_hasSecurityUpdates;
+    }
 
     QStringList loadedModules() const;
-    bool needsReboot() const { return m_needsReboot; }
+    bool needsReboot() const
+    {
+        return m_needsReboot;
+    }
 
     void setBusy(bool isBusy);
-    bool isBusy() const { return m_isBusy; }
+    bool isBusy() const
+    {
+        return m_isBusy;
+    }
 
 public Q_SLOTS:
     void recheckSystemUpdateNeeded();
@@ -60,12 +72,12 @@ public Q_SLOTS:
     void showDiscoverUpdates();
     void showUpdatesNotification();
     void reboot();
-    void foundUpgradeAction(UpgradeAction* action);
+    void foundUpgradeAction(UpgradeAction *action);
 
 Q_SIGNALS:
     void stateChanged();
     bool needsRebootChanged(bool needsReboot);
-    void newUpgradeAction(UpgradeAction* action);
+    void newUpgradeAction(UpgradeAction *action);
     bool busyChanged(bool isBusy);
 
 private:
@@ -73,17 +85,17 @@ private:
     void updateStatusNotifier();
     void refreshUnattended();
 
-    QList<BackendNotifierModule*> m_backends;
+    QList<BackendNotifierModule *> m_backends;
     QTimer m_timer;
     bool m_hasSecurityUpdates = false;
     bool m_hasUpdates = false;
     bool m_needsReboot = false;
     bool m_isBusy = false;
-    QNetworkConfigurationManager* m_manager = nullptr;
+    QNetworkConfigurationManager *m_manager = nullptr;
     QPointer<KNotification> m_updatesAvailableNotification;
-    UnattendedUpdates* m_unattended = nullptr;
+    UnattendedUpdates *m_unattended = nullptr;
     KConfigWatcher::Ptr m_settingsWatcher;
-    class UpdatesSettings* m_settings;
+    class UpdatesSettings *m_settings;
 };
 
-#endif //ABSTRACTKDEDMODULE_H
+#endif // ABSTRACTKDEDMODULE_H
